@@ -23,8 +23,9 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QRegularExpression>
+#include <KLocalizedString>
 
-RenameCategory KDebugSettingsUtil::parseRenameCategory(QString line)
+RenameCategory KDebugSettingsUtil::parseRenameCategory(QString line, const QString &filename)
 {
     RenameCategory category;
     int pos = line.indexOf(QLatin1Char('#'));
@@ -39,7 +40,8 @@ RenameCategory KDebugSettingsUtil::parseRenameCategory(QString line)
     line = line.simplified();
     const int space = line.indexOf(QLatin1Char(' '));
     if (space == -1) {
-        qCWarning(KDEBUGSETTINGS_LOG) << "No space:" << line << endl;
+        qCWarning(KDEBUGSETTINGS_LOG) << "Invalid categories file. Missing space. Syntax is logname<space>description + optional element. Line: "
+                                      << line << " from file:" << filename << endl;
         return category;
     }
 
@@ -64,7 +66,7 @@ RenameCategory::List KDebugSettingsUtil::readRenameCategories(const QString &fil
         ts.setCodec("ISO-8859-1");
         while (!ts.atEnd()) {
             data = ts.readLine().simplified();
-            const RenameCategory category = parseRenameCategory(data);
+            const RenameCategory category = parseRenameCategory(data, filename);
             if (category.isValid()) {
                 insertCategories.append(category);
             }
@@ -73,7 +75,7 @@ RenameCategory::List KDebugSettingsUtil::readRenameCategories(const QString &fil
     return insertCategories;
 }
 
-KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line)
+KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line, const QString &filename)
 {
     KdeLoggingCategory category;
     const int pos = line.indexOf(QLatin1Char('#'));
@@ -88,45 +90,100 @@ KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line)
     line = line.simplified();
     const int space = line.indexOf(QLatin1Char(' '));
     if (space == -1) {
-        qCWarning(KDEBUGSETTINGS_LOG) << "No space:" << line << endl;
+        qCWarning(KDEBUGSETTINGS_LOG) << "Invalid categories file. Missing space. Syntax is logname<space>description + optional element. Line: "
+                                      << line << " from file:" << filename << endl;
         return category;
     }
-#if 0
-    //log linux (foo)
-
-    const QString logName = line.left(space);
-
-    const QString description = line.mid(space).simplified();
-#else
     QString logName;
     QString description;
-    QString defaultCategory;
+    QString defaultSeverity;
+    QString identifier;
+
+#if 1
+
+    //TODO create an unique regularexpression
+
     static const QRegularExpression regularExpressionUser(QStringLiteral("^([\\w._-]+)\\s*(.*)$"));
     QRegularExpressionMatch match = regularExpressionUser.match(line);
     if (match.hasMatch()) {
         logName = match.captured(1);
         description = match.captured(2);
-        //qDebug() << " logName"<<logName<<" description " << description << " line " << line;
     }
 
-    static const QRegularExpression regularExpressionDefaultCategory(QStringLiteral("^(.*)\\s+\\[(DEBUG|INFO|WARNING|CRITICAL)\\]$"));
-    QRegularExpressionMatch match2 = regularExpressionDefaultCategory.match(description);
-    QString defaultCategoryCaptured;
-    if (match.hasMatch()) {
-        const QString descriptionCaptured = match2.captured(1);
-        defaultCategoryCaptured = match2.captured(2);
-        if (!descriptionCaptured.isEmpty() && !defaultCategoryCaptured.isEmpty()) {
+    bool newFormatFound = false;
+    static const QRegularExpression regularExpressionDefaultSeverityNewFormat(QStringLiteral("^(.*)\\s+DEFAULT_SEVERITY\\s+\\[(DEBUG|INFO|WARNING|CRITICAL)\\](?:\\s+(.*))?"));
+    QRegularExpressionMatch match3 = regularExpressionDefaultSeverityNewFormat.match(description);
+    QString defaultSeverityCaptured;
+    QString potentialIdentifier;
+    if (match3.hasMatch()) {
+        newFormatFound = true;
+        const QString descriptionCaptured = match3.captured(1);
+        defaultSeverityCaptured = match3.captured(2);
+        potentialIdentifier = match3.captured(3);
+        if (!descriptionCaptured.isEmpty() && !defaultSeverityCaptured.isEmpty()) {
             description = descriptionCaptured;
-            defaultCategory = defaultCategoryCaptured;
+            defaultSeverity = defaultSeverityCaptured;
             //qDebug() << " match.captured(1);" << descriptionCaptured;
             //qDebug() << " match.captured(2);" << defaultCategoryCaptured;
         }
     }
-#endif
 
-    category.logName = logName;
+    if (potentialIdentifier.isEmpty()) {
+        static const QRegularExpression regularExpressionDefaultIdentifierNewFormat(QStringLiteral("^(.*)\\s+IDENTIFIER\\s+\\[(.*)\\]"));
+        QRegularExpressionMatch match4 = regularExpressionDefaultIdentifierNewFormat.match(description);
+        if (match4.hasMatch()) {
+            newFormatFound = true;
+            const QString descriptionCaptured = match4.captured(1);
+            const QString identifierCaptured = match4.captured(2);
+            if (!descriptionCaptured.isEmpty() && !identifierCaptured.isEmpty()) {
+                description = descriptionCaptured;
+                identifier = identifierCaptured;
+                //qDebug() << " match.captured(1);" << descriptionCaptured;
+                //qDebug() << " match.captured(2);" << identifierCaptured;
+            }
+        }
+    } else {
+        static const QRegularExpression regularExpressionDefaultIdentifierNewFormat2(QStringLiteral("IDENTIFIER\\s+\\[(.*)\\]"));
+        QRegularExpressionMatch match4 = regularExpressionDefaultIdentifierNewFormat2.match(potentialIdentifier);
+        if (match4.hasMatch()) {
+            newFormatFound = true;
+            const QString identifierCaptured = match4.captured(1);
+            if (!identifierCaptured.isEmpty()) {
+                identifier = identifierCaptured;
+            }
+        }
+    }
+
+    if (!newFormatFound) {
+        //Old format.
+        static const QRegularExpression regularExpressionDefaultSeverityOldFormat(QStringLiteral("^(.*)\\s+\\[(DEBUG|INFO|WARNING|CRITICAL)\\]"));
+        QRegularExpressionMatch match2 = regularExpressionDefaultSeverityOldFormat.match(description);
+        if (match2.hasMatch()) {
+            const QString descriptionCaptured = match2.captured(1);
+            defaultSeverityCaptured = match2.captured(2);
+            if (!descriptionCaptured.isEmpty() && !defaultSeverityCaptured.isEmpty()) {
+                description = descriptionCaptured;
+                defaultSeverity = defaultSeverityCaptured;
+                //qDebug() << " match.captured(1);" << descriptionCaptured;
+                //qDebug() << " match.captured(2);" << defaultCategoryCaptured;
+            }
+        }
+    }
+#else
+    static const QRegularExpression regularExpressionUser(QStringLiteral("^([\\w._-]+)\\s*([\\w._-\\(\\)\\s*]+)\\s*(?:\\[(DEBUG|INFO|WARNING|CRITICAL)\\])?$"));
+    QRegularExpressionMatch match = regularExpressionUser.match(line);
+    if (match.hasMatch()) {
+        logName = match.captured(1);
+        description = match.captured(2);
+        defaultSeverity = match.captured(3);
+        identifier = match.captured(4);
+    }
+
+#endif
+    category.categoryName = logName;
     category.description = description;
-    category.defaultCategory = defaultCategoryCaptured;
+    category.defaultSeverity = defaultSeverity;
+    category.identifierName = identifier;
     return category;
 }
 
@@ -143,13 +200,16 @@ KdeLoggingCategory::List KDebugSettingsUtil::readLoggingCategoriesForInserting(c
         ts.setCodec("ISO-8859-1");
         while (!ts.atEnd()) {
             data = ts.readLine().simplified();
-            const KdeLoggingCategory category = parseLineKdeLoggingCategory(data);
+            const KdeLoggingCategory category = parseLineKdeLoggingCategory(data, filename);
             if (category.isValid()) {
                 bool needToAppend = true;
                 for (const KdeLoggingCategory &cat : qAsConst(categoriesList)) {
                     if (cat == category) {
                         needToAppend = false;
                         break;
+                    } else if (cat.categoryName == category.categoryName) {
+                        qCWarning(KDEBUGSETTINGS_LOG) << "Duplicate categories, it's a bug. Please verify: categorie:" << cat.categoryName << " filename : "<< filename;
+                        needToAppend = false;
                     }
                 }
                 if (needToAppend) {
@@ -173,7 +233,7 @@ void KDebugSettingsUtil::readLoggingCategories(const QString &filename, KdeLoggi
         ts.setCodec("ISO-8859-1");
         while (!ts.atEnd()) {
             data = ts.readLine().simplified();
-            const KdeLoggingCategory category = parseLineKdeLoggingCategory(data);
+            const KdeLoggingCategory category = parseLineKdeLoggingCategory(data, filename);
             if (category.isValid()) {
                 if (checkCategoryList) {
                     bool needToAppend = true;
@@ -181,6 +241,9 @@ void KDebugSettingsUtil::readLoggingCategories(const QString &filename, KdeLoggi
                         if (cat == category) {
                             needToAppend = false;
                             break;
+                        } else if (cat.categoryName == category.categoryName) {
+                            qCWarning(KDEBUGSETTINGS_LOG) << "Duplicate categories, it's a bug. Please verify: categorie:" << cat.categoryName << " filename : "<< filename;
+                            needToAppend = false;
                         }
                     }
                     if (needToAppend) {
@@ -351,3 +414,32 @@ LoggingCategory::LoggingType KDebugSettingsUtil::convertCategoryTypeFromString(c
     qCWarning(KDEBUGSETTINGS_LOG) << "Default category is unknown: " << str;
     return LoggingCategory::Info;
 }
+
+QString KDebugSettingsUtil::convertCategoryTypeToString(LoggingCategory::LoggingType type)
+{
+    QString str;
+    switch (type) {
+    case LoggingCategory::All:
+        str = i18n("All Debug Messages");
+        break;
+    case LoggingCategory::Info:
+        str = i18n("Info Messages");
+        break;
+    case LoggingCategory::Warning:
+        str = i18n("Warning Messages");
+        break;
+    case LoggingCategory::Debug:
+        str = i18n("Debug Messages");
+        break;
+    case LoggingCategory::Critical:
+        str = i18n("Critical Messages");
+        break;
+    case LoggingCategory::Off:
+        str = i18n("No Debug Messages");
+        break;
+    case LoggingCategory::Undefined:
+        str = i18n("Undefined");
+        break;
+    }
+    return str;
+}
